Index: talk/session/media/channelmanager.h |
diff --git a/talk/session/media/channelmanager.h b/talk/session/media/channelmanager.h |
index 81cb3eed61e591e3d8c0b3bc9ac457d8125f496d..d65dd9d89f08010933c8e96cba2cfe3570bcec93 100644 |
--- a/talk/session/media/channelmanager.h |
+++ b/talk/session/media/channelmanager.h |
@@ -101,8 +101,9 @@ class ChannelManager : public rtc::MessageHandler, |
// The operations below all occur on the worker thread. |
- // Creates a voice channel, to be associated with the specified session. |
- VoiceChannel* CreateVoiceChannel(BaseSession* session, |
+ // Creates a voice channel, to be associated with the specified |
+ // TransportController. |
+ VoiceChannel* CreateVoiceChannel(TransportController* transport_controller, |
const std::string& content_name, |
bool rtcp, |
const AudioOptions& options); |
@@ -110,22 +111,23 @@ class ChannelManager : public rtc::MessageHandler, |
void DestroyVoiceChannel(VoiceChannel* voice_channel, |
VideoChannel* video_channel); |
// TODO(pbos): Remove as soon as all call sites specify VideoOptions. |
- VideoChannel* CreateVideoChannel(BaseSession* session, |
+ VideoChannel* CreateVideoChannel(TransportController* transport_controller, |
const std::string& content_name, |
bool rtcp, |
VoiceChannel* voice_channel); |
// Creates a video channel, synced with the specified voice channel, and |
- // associated with the specified session. |
- VideoChannel* CreateVideoChannel(BaseSession* session, |
+ // associated with the specified TransportController. |
+ VideoChannel* CreateVideoChannel(TransportController* transport_controller, |
const std::string& content_name, |
bool rtcp, |
const VideoOptions& options, |
VoiceChannel* voice_channel); |
// Destroys a video channel created with the Create API. |
void DestroyVideoChannel(VideoChannel* video_channel); |
- DataChannel* CreateDataChannel( |
- BaseSession* session, const std::string& content_name, |
- bool rtcp, DataChannelType data_channel_type); |
+ DataChannel* CreateDataChannel(TransportController* transport_controller, |
+ const std::string& content_name, |
+ bool rtcp, |
+ DataChannelType data_channel_type); |
// Destroys a data channel created with the Create API. |
void DestroyDataChannel(DataChannel* data_channel); |
@@ -247,21 +249,22 @@ class ChannelManager : public rtc::MessageHandler, |
bool InitMediaEngine_w(); |
void DestructorDeletes_w(); |
void Terminate_w(); |
- VoiceChannel* CreateVoiceChannel_w(BaseSession* session, |
+ VoiceChannel* CreateVoiceChannel_w(TransportController* transport_controller, |
const std::string& content_name, |
bool rtcp, |
const AudioOptions& options); |
void DestroyVoiceChannel_w(VoiceChannel* voice_channel, |
VideoChannel* video_channel); |
- VideoChannel* CreateVideoChannel_w(BaseSession* session, |
+ VideoChannel* CreateVideoChannel_w(TransportController* transport_controller, |
const std::string& content_name, |
bool rtcp, |
const VideoOptions& options, |
VoiceChannel* voice_channel); |
void DestroyVideoChannel_w(VideoChannel* video_channel); |
- DataChannel* CreateDataChannel_w( |
- BaseSession* session, const std::string& content_name, |
- bool rtcp, DataChannelType data_channel_type); |
+ DataChannel* CreateDataChannel_w(TransportController* transport_controller, |
+ const std::string& content_name, |
+ bool rtcp, |
+ DataChannelType data_channel_type); |
void DestroyDataChannel_w(DataChannel* data_channel); |
bool SetAudioOptions_w(const AudioOptions& options, int delay_offset, |
const Device* in_dev, const Device* out_dev); |